function mosaic_reform, mosaic, pnx, px0, py0, overwrite=overwrite
;+
;   Name: mosaic_reform
;
;   Purpose: reformat large 2D->3D  (application of RSI 'reform')
;
;   Input Parameters
;     mosaic - 2D image to tile
;     pnx - size of one tile in pixels (for now, pny=pnx) -
;           default is .25(mosaic)
;  
;   Output Parameters:
;     function returns 3D, size=(pnx, pny, number_tiles)
;     px0 -  derived lower left X coord for each tile
;     py0 -  derived lower left Y coord for each tile  
;  
;   History:
;      30-July-1998 - S.L.Freeland - originally for TRACE FD -> www image map
;-  
if not data_chk(mosaic,/nimage) eq 1 then begin
  box_message,'IDL> image3d=mosaic_reform(image2d [, pnx, px0, py0] 
  return,-1
endif  
nx=data_chk(mosaic,/nx)
ny=data_chk(mosaic,/ny)

if n_elements(pnx) eq 0 then pnx=nx/4
pny=pnx    
if nx mod pnx ne 0 then begin  ; -------- this needs work --------
   box_message,'Boosting mosaic...'
   mosaic=make_array(nx + (nx mod pnx), ny + (ny  mod pny), type=data_chk(mosaic,/type))
endif

n_pieces=(nx/pnx)^2           ; number of "tiles"
nps=nx/pnx                    ; "tiles" per side

; derive NX/NY vectors for subarrays
px0=reform(rebin(indgen(nps)*pnx,nps,nps,/samp),nps^2) & px1=px0+(pnx-1)
py0=(indgen(nps^2)*pny/ny)*pny & py1=py0+(pny-1)

retval=reform(mosaic,pnx,pny,n_pieces, overwrite=overwrite)
for i=0,n_pieces-1 do $
    retval(0,0,i)=mosaic(px0(i):px1(i),py0(i):py1(i))  ; insert 2D->3D

return,retval
end
